summaryrefslogtreecommitdiff
path: root/src/include/taler_exchange_service.h
diff options
context:
space:
mode:
authorChristian Grothoff <christian@grothoff.org>2023-02-02 17:06:47 +0100
committerChristian Grothoff <christian@grothoff.org>2023-02-02 17:06:47 +0100
commitf60b09f8efbab6b6f30ffc63b52c7520bcd74226 (patch)
treefdee619e3bc669dcb8a7dfd57432e773de7ac7fc /src/include/taler_exchange_service.h
parent3898054b1070db0c6be0fa9f6772637069aa34e2 (diff)
downloadexchange-f60b09f8efbab6b6f30ffc63b52c7520bcd74226.tar.gz
exchange-f60b09f8efbab6b6f30ffc63b52c7520bcd74226.tar.bz2
exchange-f60b09f8efbab6b6f30ffc63b52c7520bcd74226.zip
add logic to parse AML decision response
Diffstat (limited to 'src/include/taler_exchange_service.h')
-rw-r--r--src/include/taler_exchange_service.h8
1 files changed, 5 insertions, 3 deletions
diff --git a/src/include/taler_exchange_service.h b/src/include/taler_exchange_service.h
index 277e658e9..7c61b7b5e 100644
--- a/src/include/taler_exchange_service.h
+++ b/src/include/taler_exchange_service.h
@@ -4492,12 +4492,12 @@ struct TALER_EXCHANGE_AmlDecisionResponse
/**
* Array of KYC data collections returned by the exchange.
*/
- const struct TALER_EXCHANGE_KycHistoryDetail *kyc_history;
+ const struct TALER_EXCHANGE_KycHistoryDetail *kyc_attributes;
/**
* Length of the @e kyc_history array.
*/
- unsigned int kyc_history_length;
+ unsigned int kyc_attributes_length;
} success;
@@ -4531,6 +4531,7 @@ struct TALER_EXCHANGE_LookupAmlDecision;
* @param exchange_url HTTP base URL for the exchange
* @param h_payto which account to return the decision history for
* @param officer_priv private key of the deciding AML officer
+ * @param history true to return the full history, otherwise only the last decision
* @param cb function to call with the exchange's result
* @param cb_cls closure for @a cb
* @return the request handle; NULL upon error
@@ -4541,6 +4542,7 @@ TALER_EXCHANGE_lookup_aml_decision (
const char *exchange_url,
const struct TALER_PaytoHashP *h_payto,
const struct TALER_AmlOfficerPrivateKeyP *officer_priv,
+ bool history,
TALER_EXCHANGE_LookupAmlDecisionCallback cb,
void *cb_cls);
@@ -4492,12 +4492,12 @@ struct TALER_EXCHANGE_AmlDecisionResponse
/**
- * Length of the @e kyc_history array.
+ * Length of the @e kyc_attributes array.
*/